@@ -1,7 +1,4 @@
-import { ReactNode } from 'react';
-import { Path, UseFormReturn } from 'react-hook-form';
-
-import { SelectableValue } from '@grafana/data';
+import { Path } from 'react-hook-form';
 
 import {
   BitbucketRepositoryConfig,
@@ -17,26 +14,6 @@ import {
 export type RepositoryType = RepositorySpec['type'];
 export type RepoWorkflows = RepositorySpec['workflows'];
 
-// Field configuration interface
-export interface RepositoryFieldData {
-  label: string;
-  type: 'text' | 'secret' | 'switch' | 'select' | 'checkbox' | 'custom' | 'component' | 'number';
-  description?: string | ReactNode;
-  placeholder?: string;
-  path?: Path<RepositoryFormData>; // Optional nested field path, e.g., 'sync.intervalSeconds'
-  validation?: {
-    required?: boolean | string;
-    message?: string;
-    validate?: (value: unknown) => boolean | string;
-  };
-  defaultValue?: SelectableValue<string> | string | boolean;
-  options?: Array<SelectableValue<string>>;
-  multi?: boolean;
-  allowCustomValue?: boolean;
-  hidden?: boolean;
-  content?: (setValue: UseFormReturn<RepositoryFormData>['setValue']) => ReactNode; // For custom fields
-}
-
 export type RepositoryFormData = Omit<RepositorySpec, 'workflows' | RepositorySpec['type']> &
   BitbucketRepositoryConfig &
   GitRepositoryConfig &
@@ -62,14 +39,6 @@ export type ConnectionFormData = {
   privateKey?: string;
 };
 
-// Section configuration
-export interface RepositorySection {
-  name: string;
-  id: string;
-  hidden?: boolean;
-  fields: RepositorySettingsField[];
-}
-
 // Added to DashboardDTO to help editor
 export interface ProvisioningPreview {
   repo: string;
